@@ -24,3 +24,6 @@ loaf.bake(
 
 loaf.test()
 loaf.query("SELECT * FROM public.user")
+
+print("lol "
+      "lmao")
